@@ -43,11 +43,7 @@
 #include "cpl_string.h"
 #include "cpl_vsi.h"
 
-#if defined(_WIN32) && !defined(unix)
-#  include <mbctype.h>  // Multibyte chars stuff.
-#endif
-
-CPL_CVSID("$Id: mitab_utils.cpp 6508d9ac778fff47e6ef4eef3a3e6b70556f3814 2018-03-27 14:28:44 +0200 Even Rouault $")
+CPL_CVSID("$Id: mitab_utils.cpp 0286372b17ff46a40069969c721c1476fd4a45f7 2018-09-17 15:19:47 +0200 Even Rouault $")
 
 /**********************************************************************
  *                       TABGenerateArc()
@@ -481,13 +477,6 @@ char *TABCleanFieldName(const char *pszSrcName)
             "'%s' will be used instead.", pszSrcName, pszNewName);
     }
 
-#if defined(_WIN32) && !defined(unix)
-    // On Windows, check if we're using a double-byte codepage, and
-    // if so then just keep the field name as is.
-    if (_getmbcp() != 0)
-        return pszNewName;
-#endif
-
     // According to the MapInfo User's Guide (p. 240, v5.5).
     // New Table Command:
     //  Name:
