@@ -108,7 +108,7 @@
 #include "cpl_vsi_virtual.h"
 
 
-CPL_CVSID("$Id: cpl_vsil_gzip.cpp e3de16f66f8aa84f9027cc4d8b1beddab22442a8 2018-06-19 17:52:53 -0700 Kurt Schwehr $")
+CPL_CVSID("$Id: cpl_vsil_gzip.cpp 93c43dbc8e1af7ce7a79e3337253347fea73abba 2018-07-26 10:06:29 +0200 Even Rouault $")
 
 constexpr int Z_BUFSIZE = 65536;  // Original size is 16384
 constexpr int gz_magic[2] = {0x1f, 0x8b};  // gzip magic header
@@ -722,13 +722,6 @@ int VSIGZipHandle::gzseek( vsi_l_offset offset, int whence )
         offset *= 1024 * 1024;
     }
 
-    if( // whence == SEEK_END ||
-        z_err == Z_ERRNO || z_err == Z_DATA_ERROR )
-    {
-        CPL_VSIL_GZ_RETURN(-1);
-        return -1L;
-    }
-
     // Rest of function is for reading only.
 
     // Compute absolute position.
@@ -748,6 +741,12 @@ int VSIGZipHandle::gzseek( vsi_l_offset offset, int whence )
             return -1L;
     }
 
+    if( z_err != Z_OK && z_err != Z_STREAM_END )
+    {
+        CPL_VSIL_GZ_RETURN(-1);
+        return -1L;
+    }
+
     for( unsigned int i = 0;
          i < m_compressed_size / snapshot_byte_interval + 1;
          i++ )
@@ -898,13 +897,6 @@ size_t VSIGZipHandle::Read( void * const buf, size_t const nSize,
              static_cast<int>(nMemb));
 #endif
 
-    if( z_err == Z_DATA_ERROR || z_err == Z_ERRNO )
-    {
-        z_eof = 1;  // To avoid infinite loop in reader code.
-        in = 0;
-        CPL_VSIL_GZ_RETURN(0);
-        return 0;
-    }
     if( (z_eof && in == 0) || z_err == Z_STREAM_END )
     {
         z_eof = 1;
@@ -1108,20 +1100,22 @@ size_t VSIGZipHandle::Read( void * const buf, size_t const nSize,
     }
     crc = crc32(crc, pStart, static_cast<uInt>(stream.next_out - pStart));
 
-    if( len == stream.avail_out &&
-        (z_err == Z_DATA_ERROR || z_err == Z_ERRNO || z_err == Z_BUF_ERROR) )
+    size_t ret = (len - stream.avail_out) / nSize;
+    if( z_err != Z_OK && z_err != Z_STREAM_END )
     {
         z_eof = 1;
         in = 0;
-        CPL_VSIL_GZ_RETURN(0);
-        return 0;
+        CPLError(CE_Failure, CPLE_AppDefined,
+                 "In file %s, at line %d, decompression failed with "
+                 "z_err = %d, return = %d",
+                 __FILE__, __LINE__, z_err, static_cast<int>(ret));
     }
+
 #ifdef ENABLE_DEBUG
     CPLDebug("GZIP", "Read return %d (z_err=%d, z_eof=%d)",
-             static_cast<int>((len - stream.avail_out) / nSize),
-             z_err, z_eof);
+             static_cast<int>(ret), z_err, z_eof);
 #endif
-    return static_cast<int>(len - stream.avail_out) / nSize;
+    return ret;
 }
 
 /************************************************************************/
